SELECT 10 Summary - Criterion.rs

## SELECT 10

### Violin Plot

This chart shows the relationship between function/parameter and iteration time. The thickness of the shaded region indicates the probability that a measurement of the given function/parameter would take a particular length of time.

#### SELECT 10/aiomysql

#### SELECT 10/asyncmy

#### SELECT 10/mysqlclient

#### SELECT 10/pymysql

#### SELECT 10/pyro-async

#### SELECT 10/pyro-sync